"""
///
/// @file HabsoluteState.py
///
/// @brief AUTOGENERATED FILE! ONLY EDIT IF YOU ARE A MACHINE!
///
/// @core c4674f111fc72bad86b69ef5e7f862f75f59d86f
///
/// @build 6a54779ef7f5d112e58f4877e4667f33623592a3
///
/// @date 2023-02-23 14:31:03
///
/// @author Dephy, Inc.
"""
# pylint: disable=duplicate-code

from ctypes import Structure, c_int


class HabsoluteState(Structure):
    _pack_ = 1
    _fields_ = [
        ("device_family", c_int),
        ("variable_label", c_int),
        ("include files:", c_int),
        ("state_time", c_int),
        ("ank_ang", c_int),
        ("ank_vel", c_int),
        ("adc_0", c_int),
        ("adc_1", c_int),
        ("adc_2", c_int),
        ("adc_3", c_int),
        ("adc_4", c_int),
        ("adc_5", c_int),
        ("adc_6", c_int),
        ("adc_7", c_int),
        ("genvar_0", c_int),
        ("genvar_1", c_int),
        ("genvar_2", c_int),
        ("genvar_3", c_int),
        ("status", c_int),
        ("SystemTime", c_int),
    ]
